#
# spec file for package feroxbuster
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2022-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           feroxbuster
Version:        2.11.0
Release:        1.3
Summary:        A recursive content discovery tool
License:        MIT
Group:          Productivity/Networking/Diagnostic
URL:            https://epi052.github.io/feroxbuster-docs/
#Git-Clone:     https://github.com/epi052/feroxbuster.git
Source:         https://github.com/epi052/feroxbuster/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  rust
Suggests:       seclists

%description
Forced browsing is an attack where the aim is to enumerate and access
resources that are not referenced by the web application, but are
still accessible by an attacker.

feroxbuster uses brute force combined with a wordlist to search for
unlinked content in target directories. These resources may store
sensitive information about web applications and operational systems,
such as source code, credentials, internal network addressing, etc...

This attack is also known as Predictable Resource Location, File
Enumeration, Directory Enumeration, and Resource Enumeration.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Networking/Diagnostic
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%autosetup -p 1 -a 1

%build
%{cargo_build}

%install
cargo install --no-track --root=%{buildroot}%{_prefix} --path .
install -D -m0644 shell_completions/feroxbuster.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}

%files
%license LICENSE
%doc ferox-config.toml.example README.md
%{_bindir}/feroxbuster

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Tue Sep 17 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11.0
  What's Changed
  * add --scan-dir-listings
  * add --request-file
  * add --protocol
  * add --limit-bars
  Brief descriptions
  * --request-file and --protocol - read in a raw http request
    file, from burp or similar
  * --scan-dir-listings - force recursion into folders where
    directory listing is enabled
  * --limit-bars - cap the number of progress bars displayed
  Documentation
  * --request-file and --protocol
  * --scan-dir-listings
  * --limit-bars
* Tue Jun 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10.4
  * --filter-regex now looks at headers in addition to response
    body.
  * clarified wording for headers in ferox-config.toml
  * scan management menu now shows the estimated time left to scan.
  * made --cookies parsing more robust.
  * fixed an issue where estimated time to complete would show 0s
    before the scan was finished.
* Sat Apr 27 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10.3
  * improve json logs for post processing.
  * included configuration field in state file.
  * using --data implies POST HTTP verb.
  * fixed mishandling of whitespace for supplied request headers.
* Fri Mar  1 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10.2
  * removed scan target headers from feroxbuster-update check.
  * --collect-backups accepts custom backup extension list.
  * fixed issue where --silent included too much info on found dir.
  * --parallel time limit enforced on individual directories
    instead of main thread.
  * query fontconfig to determine if Noto Color Emoji is installed.
  * updated upstream library that was causing tokio-runtime-worker
    panics; they're correctly reported as Err from the library now.
  * fixed issue where early redirect loop would cause ferox to hang
    indefinitely.
* Fri Nov 24 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10.1
  * fixed scan menu range issue.
  * enable reading extensions from file.
  * fixed collect backups filtering.
  * added http/2 support.
  * allowed --json in conjunction with --silent.
- Update to version 2.10.0
  * Adds server and client certificate management; enables mTLS.
  - -server-certs
  - -client-cert
  - -client-key
- Update to version 2.9.5
  * support raw urls.
- Update to version 2.9.4
  * reduced memory usage overall
  * improved speed during link extraction
- Update to version 2.9.3
  * added extensions and status codes into auto filtering
    decision calculus.
* Sat Mar 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.2
  https://github.com/epi052/feroxbuster/releases
* Sat Jan 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.3
  * FIX 732 ensure --no-state is respected even through
  - -time-limit.
  * fixed #716; wordlist entries with leading slash are trimmed.
  * fixed #743; redirects always show full url as Location.
  * fixed #748; cancelled scans persist across ctrl+c.
* Wed Nov 16 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.2
  * fix double dir scan.
  * fixed invalid uri exception during extraction.
  * updated dependencies.
* Sun May 22 2022 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.7.1
